package com.yixin.ms.server;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.beust.jcommander.internal.Lists;
import com.yixin.ms.boot.restful.RestCode;
import com.yixin.ms.model.enums.HealthCodeLevelEnum;
import com.yixin.ms.model.vo.HealtCodeNucleinVO;
import com.yixin.ms.model.vo.HealtCodeTypeVO;
import com.yixin.ms.model.vo.HealtCodeUserVO;
import com.yixin.ms.server.dto.GzhHealthDTO;
import com.yixin.ms.server.dto.NucleicTestDTO;
import com.yixin.ms.server.dto.VaccinateDTO;
import com.yixin.ms.server.vo.GzhHealthVO;
import com.yixin.ms.server.vo.HealthResultVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author: lileilei
 * @date: 2022/8/17 14:19
 * @description: 贵州健康码服务
 */
@Slf4j
@Component
public class GuizhouHealthServer {
    @Value("${health.guizhou.gzhHealthByIdCardUrl}")
    private String gzhHealthByIdCardUrl;

    /**
     * 通过身份证查询健康码信息
     * @param dto
     * @return
     */
    public HealtCodeUserVO gzhHealthByIdCard(GzhHealthDTO dto) {
        HealtCodeUserVO userVO = null;
        String body = HttpUtil.post(gzhHealthByIdCardUrl, JSON.toJSONString(dto));
        log.info("通过身份证查询健康码信息响应内容: {}", body);
        HealthResultVO resultVO = JSON.parseObject(body, HealthResultVO.class);
        if(resultVO.getCode().equals(Integer.valueOf(RestCode.SUCCESS.getCode()))){
            GzhHealthVO gzhHealthVO = JSON.parseObject(JSON.toJSONString(resultVO.getData()), GzhHealthVO.class);
            resultVO.setData(gzhHealthVO);
            userVO = new HealtCodeUserVO();
            List<VaccinateDTO> vaccinate = gzhHealthVO.getVaccinate();
            if(CollectionUtil.isNotEmpty(vaccinate)){
                userVO.setUsername(vaccinate.stream().findFirst().get().getChil_name());
                userVO.setVaccineNum(String.valueOf(vaccinate.size()));
            }

            userVO.setIdNumber(gzhHealthVO.getPhone());
            userVO.setData(Lists.newArrayList(new HealtCodeTypeVO().setMzt(HealthCodeLevelEnum.codeOf(gzhHealthVO.getColor()).getDesc())));

            if(CollectionUtil.isNotEmpty(gzhHealthVO.getNucleicTest())){
                NucleicTestDTO nucleicTestDTO = gzhHealthVO.getNucleicTest().stream().findFirst().get();
                userVO.setNuclein(Lists.newArrayList(new HealtCodeNucleinVO().setChecktime(DateUtil.parseDateTime(nucleicTestDTO.getHsjcsj())).setResult(nucleicTestDTO.getHsjcjg())));
            }else{
                userVO.setNuclein(Lists.newArrayList());
            }
        }

        return userVO;
    }
}
